package com.install4j.api.beaninfo;

/**
 * Base class for screen bean infos.
 * <p>Using this class is not strictly required. In principle, you could also set values for the <tt>ATTRIBUTE_*</tt> constants in the bean descriptor
 * of an unrelated bean info class.
 */
public class ScreenBeanInfo extends Install4JBeanInfo {

    /**
     * @see #setDefaultQuitAfterScreen(boolean)
     */
    public static final String ATTRIBUTE_DEFAULT_QUIT_AFTER_SCREEN = "defaultQuitAfterScreen";

    /**
     * @see #setFormComponentCustomizerPlacement(CustomizerPlacement)
     */
    public static final String ATTRIBUTE_FORM_COMPONENT_CUSTOMIZER_PLACEMENT = "formComponentCustomizerPlacement";

    /**
     * @see #setAssociatedAction(String, String)
     */
    public static final String ATTRIBUTE_ASSOCIATED_ACTION = "associatedAction";

    /**
     * @see #setAssociatedAction(String, String)
     */
    public static final String ATTRIBUTE_ASSOCIATED_ACTION_TARGET_SCREEN = "associatedActionTargetScreen";

    /**
     * Same as {@link Install4JBeanInfo#Install4JBeanInfo(String, String, String, boolean, boolean, Integer, Class, Class)}.
     */
    public ScreenBeanInfo(String displayName, String shortDescription, String category, boolean multipleInstancesSupported, boolean installedFilesRequired, Integer sortKey, Class beanClass, Class customizerClass) {
        super(displayName, shortDescription, category, multipleInstancesSupported, installedFilesRequired, sortKey, beanClass, customizerClass);
    }

    /**
     * Same as {@link Install4JBeanInfo#Install4JBeanInfo(String, String, String, boolean, boolean, Integer, Class)}.
     */
    public ScreenBeanInfo(String displayName, String shortDescription, String category, boolean multipleInstancesSupported, boolean installedFilesRequired, Integer sortKey, Class beanClass) {
        super(displayName, shortDescription, category, multipleInstancesSupported, installedFilesRequired, sortKey, beanClass);
    }

    /**
     * Configures the default value of the "Quit after screen" property of the screen.
     * @param defaultQuitAfterScreen the default value
     */
    public void setDefaultQuitAfterScreen(boolean defaultQuitAfterScreen) {
        getBeanDescriptor().setValue(ATTRIBUTE_DEFAULT_QUIT_AFTER_SCREEN, Boolean.valueOf(defaultQuitAfterScreen));
    }

    /**
     * Configures the placement of the form component customizer for form screens.
     * If the screen has a form panel, a customizer for the contained form components will be added automatically.
     * @param customizerPlacement the placement
     * @see com.install4j.api.screens.FormPanelContainer
     */
    public void setFormComponentCustomizerPlacement(CustomizerPlacement customizerPlacement) {
        if (customizerPlacement != null) {
            getBeanDescriptor().setValue(ATTRIBUTE_FORM_COMPONENT_CUSTOMIZER_PLACEMENT, customizerPlacement);
        }
    }

    /**
     * Configures an associated action. If set, and the user adds the action, the install4j GUI checks if
     * an instance of the specified action is present in the list of configured actions on any screen. If not,
     * it will remind the user to add such an action or propose to add the action immediately, depending on whether
     * <tt>targetScreenClassName</tt> is <tt>null</tt>.
     * @param actionClassName the class of the associated action
     * @param targetScreenClassName the target screen. If non-null, the install4j GUI will propose to add the
     * associated action to the target screen if it cannot already be found on any screen.
     */
    public void setAssociatedAction(String actionClassName, String targetScreenClassName) {
        if (actionClassName != null) {
            getBeanDescriptor().setValue(ATTRIBUTE_ASSOCIATED_ACTION, actionClassName);
        }
        if (targetScreenClassName!= null) {
            getBeanDescriptor().setValue(ATTRIBUTE_ASSOCIATED_ACTION_TARGET_SCREEN, targetScreenClassName);
        }
    }

}
