package com.install4j.api.launcher;

import com.exe4j.runtime.*;
import com.install4j.runtime.splashscreen.JavaSplashController;

/**
 *
 * <p>This class allows you to control the splash screen of an install4j
 * launcher from your Java code.</p>
 *
 * <p>In order to use this class, please include <tt>resource/i4jruntime.jar</tt> from your
 * install4j installation into your class path. You do not need to distribute this file
 * along with your application, install4j will do this automatically for you.
 * </p>
 *
 * @author ej-technologies GmbH
 *
 */
public class SplashScreen {
    
    private static final String SYSPROP_OS_NAME = "os.name";
    private static final String OS_NAME = System.getProperty(SYSPROP_OS_NAME);

    private static ControllerInterface controllerBackend;

    /**
     * Update the status text line of the splash screen with a different message.
     * @param message the new text.
     * @throws com.install4j.api.launcher.SplashScreen.ConnectionException if there is a communication problem
     *
    */
    public static void writeMessage(String message) throws ConnectionException {
        try {
            init();
            controllerBackend.writeMessage(message);
        } catch (BaseConnectionException e) {
            throw new ConnectionException(e);
        }
    }

    /**
     * Programmatically hide the splash screen. If the "auto-off" mode
     * is enabled for the splash screen, programmatic hiding may not be necessary. In that case,
     * the splash screen will disappear when first window is shown.
     * @throws com.install4j.api.launcher.SplashScreen.ConnectionException if there is a communication problem
     */
    public static void hide() throws ConnectionException {
        try {
            init();
            controllerBackend.hide();
        } catch (BaseConnectionException e) {
            throw new ConnectionException(e);
        }
    }

    private static void init() throws BaseConnectionException {
        if (controllerBackend == null) {
            if (isWindows()) {
                controllerBackend = Exe4JController.getInstance();
            } else {
                controllerBackend = JavaSplashController.getInstance();
            }
        }
    }

    private static boolean isWindows() {
        return OS_NAME.toLowerCase().startsWith("win");
    }

    private SplashScreen() {
    }

    /**
     * <p>The exception thrown by methods of the <tt>SplashScreen</tt> class to
     * indicate that a splash screen operation was not successful.
     * </p>
     *
     * @author ej-technologies GmbH
     */
    public static class ConnectionException extends Exception {
        private ConnectionException(BaseConnectionException e) {
            super(e.getMessage());
        }
    }


}