package com.install4j.api.windows;

import com.install4j.runtime.installer.platform.win32.Win32UserInfo;

import java.util.HashMap;
import java.util.Map;

/**
 * Enumeration class for the different elevation states the current process can be in.

 * @author ej-technologies GmbH
 */
public class ElevationState {

    private static Map intValueToObject = new HashMap();

    /**
     * All processes on a system with a Windows version previous to Vista.
     */
    public static final ElevationState ELEVATION_STATE_NOT_APPLICABLE = new ElevationState(Win32UserInfo.ELEVATION_TYPE_NOT_APPLICABLE);

    /**
     * The current process is not limited and not elevated on Vista or higher. This can be a process of a non-admin user, or of an admin user when UAC is turned off.
     * You can differentiate between those two with {@link com.install4j.api.Util#hasFullAdminRights()}.
     */
    public static final ElevationState ELEVATION_STATE_DEFAULT = new ElevationState(Win32UserInfo.ELEVATION_TYPE_DEFAULT);

    /**
     * The current process runs with limited rights. UAC is turned on.
     */
    public static final ElevationState ELEVATION_STATE_LIMITED = new ElevationState(Win32UserInfo.ELEVATION_TYPE_LIMITED);

    /**
     * The current process was elevated and runs with full rights. UAC is turned on.
     */
    public static final ElevationState ELEVATION_STATE_FULL = new ElevationState(Win32UserInfo.ELEVATION_TYPE_FULL);

    private int intValue;

    private ElevationState(int intValue) {
        this.intValue = intValue;
        intValueToObject.put(new Integer(intValue), this);
    }

    static ElevationState getFromIntValue(int intValue) {
        return (ElevationState)intValueToObject.get(new Integer(intValue));
    }

    public String toString() {
        return "ElevationState{" +
                "intValue=" + intValue +
                '}';
    }
}