package com.install4j.api.windows;

import com.install4j.runtime.installer.platform.win32.Registry;

/**
 * Enumeration class for the different registry roots in the Microsoft Windows registry.

 * @author ej-technologies GmbH
 */
public class RegistryRoot {

    /**
     * Identifies the root registry key <tt>HKEY_CLASSES_ROOT</tt>.
     */
    public static final RegistryRoot HKEY_CLASSES_ROOT = new RegistryRoot(Registry.HKEY_CLASSES_ROOT, "HKEY_CLASSES_ROOT");

    /**
     * Identifies the root registry key <tt>HKEY_LOCAL_MACHINE</tt>.
     */
    public static final RegistryRoot HKEY_LOCAL_MACHINE = new RegistryRoot(Registry.HKEY_LOCAL_MACHINE, "HKEY_LOCAL_MACHINE");

    /**
     * Identifies the root registry key <tt>HKEY_CURRENT_USER</tt>.
     */
    public static final RegistryRoot HKEY_CURRENT_USER = new RegistryRoot(Registry.HKEY_CURRENT_USER, "HKEY_CURRENT_USER");

    /**
     * Identifies the root registry key <tt>HKEY_USERS</tt>.
     */
    public static final RegistryRoot HKEY_USERS = new RegistryRoot(Registry.HKEY_USERS, "HKEY_USERS");

    /**
     * Identifies the root registry key <tt>HKEY_CURRENT_CONFIG</tt>.
     */
    public static final RegistryRoot HKEY_CURRENT_CONFIG = new RegistryRoot(Registry.HKEY_CURRENT_CONFIG, "HKEY_CURRENT_CONFIG");

    private int type;
    private String name;

    private RegistryRoot(int type, String name) {
        this.type = type;
        this.name = name;
    }

    int getType() {
        return type;
    }

    public String toString() {
        return name;
    }

}
