package com.install4j.api.windows;

import com.install4j.runtime.installer.helper.InstallerUtil;
import com.install4j.runtime.installer.platform.win32.Registry;

/**
 * Enumeration class for the different views of the Microsoft Windows registry on 64-bit systems.
 *
 * You can find more information <a href="http://msdn.microsoft.com/en-us/library/aa384253%28v=VS.85%29.aspx">here</a>.

 * @author ej-technologies GmbH
 */
public class RegistryView {

    /**
     * Use the 32-bit view for a 32-bit, and the 64-bit view for a 64-bit process.
     */
    public static final RegistryView DEFAULT = new RegistryView(Registry.WOW64_DEFAULT, "Default");

    /**
     * Always use the 32-bit view stored in the special Wow6432Node key.
     */
    public static final RegistryView BIT32 = new RegistryView(Registry.WOW64_32KEY, "32-bit view");

    /**
     * Always use the 64-bit view.
     */
    public static final RegistryView BIT64 = new RegistryView(Registry.WOW64_64KEY, "64-bit view");

    private int type;
    private String name;

    private RegistryView(int type, String name) {
        this.type = type;
        this.name = name;
    }

    int getUsedType() {
        if (InstallerUtil.isAtLeastWindowsXP()) {
            return type;
        } else {
            return DEFAULT.type;
        }
    }

    public String toString() {
        return name;
    }

}